@@ -5,7 +5,7 @@ use Panda::Time;
 use Panda::Date::Rel;
 use Panda::Date::Int;
 
-our $VERSION = '2.9';
+our $VERSION = '3.0.0';
 
 =head1 NAME
 
@@ -13,7 +13,10 @@ Panda::Date - fast Date framework in C.
 
 =cut
 
-use Panda::Export {
+require Panda::XSLoader;
+Panda::XSLoader::bootstrap('Panda::Date', $VERSION);
+
+Panda::Export->import(
     E_OK         => 0,
     E_UNPARSABLE => 1,
     E_RANGE      => 2,
@@ -23,7 +26,7 @@ use Panda::Export {
     DAY          => rdate_const("1D"),
     MONTH        => rdate_const("1M"),
     YEAR         => rdate_const("1Y"),
-};
+);
 
 use overload
     '""'     => \&to_string,
