@@ -35,7 +35,7 @@ const char* date_thaw (ptime_t* epoch, const tz** zone, const char* ptr, size_t
     return ptr + znlen;
 }
 
-SV* export_transition (tztrans& trans, bool is_past) {
+SV* export_transition (pTHX_ tztrans& trans, bool is_past) {
     HV* hv = newHV();
     hv_store(hv, "offset", 6, newSViv(trans.offset),    0);
     hv_store(hv, "abbrev", 6, newSVpv(trans.abbrev, 0), 0);
@@ -49,7 +49,7 @@ SV* export_transition (tztrans& trans, bool is_past) {
     return newRV_noinc((SV*)hv);
 }
 
-HV* export_timezone (const tz* zone) {
+HV* export_timezone (pTHX_ const tz* zone) {
     HV* ret = newHV();
     
     hv_store(ret, "name", 4, newSVpv(zone->name, 0), 0);
@@ -95,10 +95,10 @@ HV* export_timezone (const tz* zone) {
     hv_store(ret, "future", 6, newRV_noinc((SV*) future), 0);
     
     AV* trans = newAV();
-    for (int i = 0; i < zone->trans_cnt; i++) av_push(trans, export_transition(zone->trans[i], false));
+    for (int i = 0; i < zone->trans_cnt; i++) av_push(trans, export_transition(aTHX_ zone->trans[i], false));
     hv_store(ret, "transitions", 11, newRV_noinc((SV*) trans), 0);
     
-    hv_store(ret, "past", 4, export_transition(zone->trans[0], true), 0);
+    hv_store(ret, "past", 4, export_transition(aTHX_ zone->trans[0], true), 0);
     
     return ret;
 }
